.. _developer:

##########################
Developer Reference Manual
##########################

:Release: |version|
:Date: |today|


The intended audience of this guide is developers who use Py-ART. For a more
general introduction to Py-ART aimed at users see the :ref:`user`.

This guide provides  documentation for all modules, function, methods, 
and classes within Py-ART, both those in the public API and private members.

Documentation is broken down by directory and module.

.. toctree::
    :maxdepth: 2
    
    core
    io
    aux_io
    config
    correct
    exceptions
    retrieve
    graph
    filters
    lazydict
    map
    util
    bridge
    testing
    _debug_info
